@@ -14,7 +14,6 @@ from PySide6.QtCore import (
 from PySide6.QtGui import Qt, QIcon
 from PySide6.QtQml import QQmlApplicationEngine
 from PySide6.QtWidgets import QApplication
-from plyer import notification
 
 import dvpn.res  # noqa
 from dvpn.config.constants import PublicVars, CLI_RESOLVE
@@ -170,7 +169,6 @@ class Bridge(QObject):
         self.disconnectChange.emit(vpn_name, False, False)
         self.connectedVPNs.discard(vpn_name)
         self.changingVPNs.discard(vpn_name)
-        notification.notify(title="DieVpn", message="Disconnected")
 
 
 def main():
